@@ -1,7 +1,7 @@
 import os
 from pathlib import Path
 
-def auto_create_folder( default_path = Path( os.environ[ 'USERPROFILE' ], "Desktop" ), folder_extend = None ):
+def auto_create_folder( default_path = Path( os.environ[ 'USERPROFILE' ], "Desktop" ), folder_extend = "task_list" ):
     default_path = Path( default_path )
     default_list = str( default_path ).split( "\\" )
     for elem in default_list:
